@@ -1,7 +1,12 @@
+# Unless explicitly stated otherwise all files in this repository are licensed under the BSD-3-Clause License.
+# This product includes software developed at Datadog (https://www.datadoghq.com/).
+# Copyright 2015-Present Datadog, Inc
+# stdlib
+import json
+
 # datadog
 from datadog import api
 from datadog.dogshell.common import report_errors, report_warnings
-from datadog.util.compat import json
 
 
 # TODO IS there a test ?
