@@ -16,11 +16,15 @@ import time
 from threading import Lock
 
 # datadog
-from datadog.dogstatsd.context import TimedContextManagerDecorator
+from datadog.dogstatsd.context import (
+    TimedContextManagerDecorator,
+    DistributedContextManagerDecorator,
+)
 from datadog.dogstatsd.route import get_default_route
 from datadog.util.compat import text
 from datadog.util.format import normalize_tags
 from datadog.version import __version__
+from typing import Optional, List, Text
 
 # Logging
 log = logging.getLogger('datadog.dogstatsd')
@@ -51,11 +55,23 @@ DEFAULT_TELEMETRY_MIN_FLUSH_INTERVAL = 10
 class DogStatsd(object):
     OK, WARNING, CRITICAL, UNKNOWN = (0, 1, 2, 3)
 
-    def __init__(self, host=DEFAULT_HOST, port=DEFAULT_PORT, max_buffer_size=None, namespace=None,
-                 constant_tags=None, use_ms=False, use_default_route=False,
-                 socket_path=None, default_sample_rate=1, disable_telemetry=False,
-                 telemetry_min_flush_interval=DEFAULT_TELEMETRY_MIN_FLUSH_INTERVAL,
-                 max_buffer_len=0):
+    def __init__(
+        self,
+        host=DEFAULT_HOST,              # type: Text
+        port=DEFAULT_PORT,              # type: int
+        max_buffer_size=None,           # type: None
+        namespace=None,                 # type: Optional[Text]
+        constant_tags=None,             # type: Optional[List[str]]
+        use_ms=False,                   # type: bool
+        use_default_route=False,        # type: bool
+        socket_path=None,               # type: Optional[Text]
+        default_sample_rate=1,          # type: float
+        disable_telemetry=False,        # type: bool
+        telemetry_min_flush_interval=(
+            DEFAULT_TELEMETRY_MIN_FLUSH_INTERVAL
+        ),                              # type: int
+        max_buffer_len=0                # type: int
+    ):  # type: (...) -> None
         """
         Initialize a DogStatsd object.
 
@@ -87,6 +103,9 @@ class DogStatsd(object):
         If set, it is appended to the constant (global) tags of the statsd client.
         :type DD_VERSION: string
 
+        :envvar DD_DOGSTATSD_DISABLE: Disable any statsd metric collection (default False)
+        :type DD_DOGSTATSD_DISABLE: boolean
+
         :param host: the host of the DogStatsd server.
         :type host: string
 
@@ -141,10 +160,16 @@ class DogStatsd(object):
                 log.warning("Port number provided in DD_DOGSTATSD_PORT env var is not an integer: \
                 %s, using %s as port number", dogstatsd_port, port)
 
+        # Check enabled
+        if os.environ.get('DD_DOGSTATSD_DISABLE') not in {'True', 'true', 'yes', '1'}:
+            self._enabled = True
+        else:
+            self._enabled = False
+
         # Connection
         self._max_payload_size = max_buffer_len
         if socket_path is not None:
-            self.socket_path = socket_path
+            self.socket_path = socket_path  # type: Optional[text]
             self.host = None
             self.port = None
             transport = "uds"
@@ -228,11 +253,12 @@ class DogStatsd(object):
             if not self.socket:
                 if self.socket_path is not None:
                     sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
-                    sock.connect(self.socket_path)
                     sock.setblocking(0)
+                    sock.connect(self.socket_path)
                     self.socket = sock
                 else:
                     sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+                    sock.setblocking(0)
                     sock.connect((self.host, self.port))
                     self.socket = sock
 
@@ -264,7 +290,13 @@ class DogStatsd(object):
             # Only send packets if there are packets to send
             self._flush_buffer()
 
-    def gauge(self, metric, value, tags=None, sample_rate=None):
+    def gauge(
+        self,
+        metric,           # type: Text
+        value,            # type: float
+        tags=None,        # type: Optional[List[str]]
+        sample_rate=None  # type: Optional[float]
+    ):  # type(...) -> None
         """
         Record the value of a gauge, optionally setting a list of tags and a
         sample rate.
@@ -274,7 +306,13 @@ class DogStatsd(object):
         """
         return self._report(metric, 'g', value, tags, sample_rate)
 
-    def increment(self, metric, value=1, tags=None, sample_rate=None):
+    def increment(
+        self,
+        metric,             # type: Text
+        value=1,            # type: float
+        tags=None,          # type: Optional[List[str]]
+        sample_rate=None    # type: Optional[float]
+    ):  # type: (...) -> None
         """
         Increment a counter, optionally setting a value, tags and a sample
         rate.
@@ -349,6 +387,34 @@ class DogStatsd(object):
         """
         return TimedContextManagerDecorator(self, metric, tags, sample_rate, use_ms)
 
+    def distributed(self, metric=None, tags=None, sample_rate=None, use_ms=None):
+        """
+        A decorator or context manager that will measure the distribution of a
+        function's/context's run time using custom metric distribution.
+        Optionally specify a list of tags or a sample rate. If the metric is not
+        defined as a decorator, the module name and function name will be used.
+        The metric is required as a context manager.
+        ::
+
+            @statsd.distributed('user.query.time', sample_rate=0.5)
+            def get_user(user_id):
+                # Do what you need to ...
+                pass
+
+            # Is equivalent to ...
+            with statsd.distributed('user.query.time', sample_rate=0.5):
+                # Do what you need to ...
+                pass
+
+            # Is equivalent to ...
+            start = time.time()
+            try:
+                get_user(user_id)
+            finally:
+                statsd.distribution('user.query.time', time.time() - start)
+        """
+        return DistributedContextManagerDecorator(self, metric, tags, sample_rate, use_ms)
+
     def set(self, metric, value, tags=None, sample_rate=None):
         """
         Sample a set value.
@@ -388,6 +454,9 @@ class DogStatsd(object):
         if value is None:
             return
 
+        if self._enabled is not True:
+            return
+
         if self._telemetry:
             self.metrics_count += 1
 
